@@ -135,7 +135,7 @@ class sqlite:
         self.__base_where_clause_string += op
         self.__base_where_clause_string += self.SPACE_CHARACTER
         self.__base_where_clause_string += self.SINGLE_QUOTES_CHARACTER
-        self.__base_where_clause_string += value
+        self.__base_where_clause_string += str(value)
         self.__base_where_clause_string += self.SINGLE_QUOTES_CHARACTER
         self.__base_where_clause_string += self.SPACE_CHARACTER
         return self
@@ -246,7 +246,7 @@ class sqlite:
         insert += " ( "
         insert += columns_string
         insert += " ) VALUES ( "
-        insert += values_string
+        insert += str(values_string)
         insert += " ); "
         return self.db.execute(insert)
 
@@ -257,7 +257,7 @@ class sqlite:
             columns_string += column_key
             columns_string += ","
             values_string += self.SINGLE_QUOTES_CHARACTER
-            values_string += column_value
+            values_string += str(column_value)
             values_string += self.SINGLE_QUOTES_CHARACTER
             values_string += ","
 
